//###########################################################################
//
// FILE:   tms470_flash_definition.h
//
// TITLE:  TMS470R1 Flash Definitions.
//
//###########################################################################
//
//  Ver  | dd mmm yyyy | Who  | Description of changes
// ======|=============|======|==============================================
//  0.01 | 14 Jun 2005 | J.M. | Created
//       |             |      |
//       |             |      |
//
//  Texas Instruments, Inc
//  Copyright Texas Instruments 2005 . All rights reserved.
//###########################################################################


#ifndef tms470_flash_definition_H
#define tms470_flash_definition_H

#ifdef __cplusplus
extern "C" {
#endif

// sector organization

struct SectorOrg
{
  unsigned short SectorCount ;              // how many sectors ... */
  unsigned long SectorSize ;                // ... of what size */
} ;


// flash definition used from the flashloader

struct FlashDef
{
  unsigned long DeviceID;                    // Manufacturer_ID << 16 ) | Device_ID
  unsigned short NumOfBanks;                 // number of physical banks in total
  unsigned short NumOfSectors;               // number of physical sectors in total
  const unsigned short *LastSectorInBank;    // pointer to arrays with last sectors in banks
  const struct SectorOrg *SectorTable;       // sector organization
  const  unsigned long *SectorBaseAddressTable; // Sector addresses
  const  unsigned long *SectorLengthTable;   // Sector length
};

//
// all data programmed into the MCU F05 flash module must be done one halfword (16 bits) at a time

typedef unsigned short flashunit ;

// this is the FlashAddressTable array size */
#define MAX_NUM_OF_SECTORS ( 18 )
#define MAX_NUM_OF_BANKS ( 4 )


#define NUM_OF_BANKS_A256 ( 1 )                  // number of banks for A256

#define NUM_OF_SECTORS_A256 ( 14 )               // number of sectors for A256

// last sectors in banks
const unsigned short BankOrg_A256[]=
{
  ( NUM_OF_SECTORS_A256 - 1 )
} ;
// sector organization for A256
const struct SectorOrg SectorOrg_A256[] =
{
  { 4, 8 * 1024UL },  // 4 x 8kbytes sectors
  { 6, 32 * 1024UL },  // 6 x 32kbytes sectors
  { 4, 8 * 1024UL },  // 4 x 8kbytes sectors
} ;

// Sector base addresses
 const unsigned long  SectorAdd_A256[]=
{0x00000000,0x00002000,0x00004000,0x00006000,
 0x00008000,0x00010000,0x00018000,0x00020000,0x00028000,0x00030000,
 0x00038000,0x0003A000,0x0003C000,0x0003E000};

// Sector addresses
 const unsigned long  SectorLength_A256[]=
{0x00000800,0x00000800,0x00000800,0x00000800,
 0x00002000,0x00002000,0x00002000,0x00002000,0x00002000,0x00002000,
 0x00000800,0x00000800,0x00000800,0x00000800};


// device definition for for A256
const struct FlashDef FlashDef_A256 =
{
  0x00000857,
  NUM_OF_BANKS_A256,
  NUM_OF_SECTORS_A256,
  BankOrg_A256,
  SectorOrg_A256,
  SectorAdd_A256,
  SectorLength_A256
} ;


// number of banks for A768 */
#define NUM_OF_BANKS_A768 ( 3 )
// number of sectors for A768 */
#define NUM_OF_SECTORS_A768 ( 18 )
// last sectors in banks */
const unsigned short BankOrg_A768[]=
{
  9,
  13,
  (NUM_OF_SECTORS_A768 -1)
} ;
// sector organization for A768 */
const struct SectorOrg SectorOrg_A768[] =
{
  { 2, 16 * 1024UL },  // 2 x 16kbytes sectors */
  { 6, 32 * 1024UL },  // 6 x 32kbytes sectors */
  { 2, 16 * 1024UL },  // 2 x 16kbytes sectors */
  { 8, 64 * 1024UL },  // 8 x 64kbytes sectors */
} ;


// Sector base addresses
 const unsigned long  SectorAdd_A768[]=
{0x00000000,0x00004000,0x00008000,0x00010000,0x00018000,0x00020000,0x00028000,0x00030000,0x00038000,0x0003c000,
 0x00040000,0x00050000,0x00060000,0x00070000,
 0x00080000,0x00090000,0x000A0000,0x000B0000};

 // Sector addresses
 const unsigned long  SectorLength_A768[]=
{0x00004000,0x00004000,0x00008000,0x00008000,0x00008000,0x00008000,0x00008000,0x00008000,0x00004000,0x00004000,
 0x00010000,0x00010000,0x00010000,0x00010000,
 0x00010000,0x00010000,0x00010000,0x00010000};




// device definition for A768 */
const struct FlashDef FlashDef_A768 =
{
  0x0000083F,
  NUM_OF_BANKS_A768,
  NUM_OF_SECTORS_A768,
  BankOrg_A768,
  SectorOrg_A768,
   SectorAdd_A768,
  SectorLength_A768,
} ;

// John Mangino 6-1-05, using A768 structures */

// device definition for A768 */
const struct FlashDef FlashDef_B768 =
{
  0x0000087F,
  NUM_OF_BANKS_A768,
  NUM_OF_SECTORS_A768,
  BankOrg_A768,
  SectorOrg_A768,
  SectorAdd_A768,
  SectorLength_A768,
} ;





////////////////////////////////////////////////////////////////////
//        B1M Flash configuration
////////////////////////////////////////////////////////////////////

// number of banks for A288 */
#define NUM_OF_BANKS_A288 ( 2 )
// number of sectors for A288 */
#define NUM_OF_SECTORS_A288 ( 9 )
// last sectors in banks */
const unsigned short BankOrg_A288[]=
{
  4,
  ( NUM_OF_SECTORS_A288 - 1 )
} ;
// sector organization for A288 */
const struct SectorOrg SectorOrg_A288[] =
{
  { 4, 8 * 1024UL },  // 4 x 8kbytes sectors */
  { 1, 224 * 1024UL },  // 1 x 224kbytes sectors */
  { 4, 64 * 1024UL },  // 4 x 64kbytes sectors */
} ;

// Sector base addresses
 const unsigned long  SectorAdd_A288[]=
{0x00000000,0x00002000,0x00004000,0x00006000,0x00008000,
 0x00040000,0x00050000,0x00060000,0x00070000};

 // Sector addresses
 const unsigned long  SectorLength_A288[]=
{0x00000800,0x00000800,0x00000800,0x00000800,0x0000e000,
0x00004000,0x00004000,0x00004000,0x00004000};


// device definition for A288 */
const struct FlashDef FlashDef_A288 =
{
  0x0000095F,
  NUM_OF_BANKS_A288,
  NUM_OF_SECTORS_A288,
  BankOrg_A288,
  SectorOrg_A288,
  SectorAdd_A288,
  SectorLength_A288,
} ;


////////////////////////////////////////////////////////////////////
//        B1M Flash configuration
////////////////////////////////////////////////////////////////////

#define NUM_OF_BANKS_B1M ( 2 )          // number of banks for B1M
#define NUM_OF_SECTORS_B1M ( 16 )       // number of sectors for B1M

// last sectors in banks
const unsigned short BankOrg_B1M[]=
{
  7,
  ( NUM_OF_SECTORS_B1M - 1 )
} ;

// sector organization for B1M */
const struct SectorOrg SectorOrg_B1M[] =
{
  { 16, 64 * 1024UL },                  // 16 x 64kbytes sectors */
} ;

// Sector base addresses
 const unsigned long  SectorAdd_B1M[]=
{0x00000000,0x00010000,0x00020000,0x00030000,0x00040000,0x00050000,0x00060000,0x00070000,0x00080000,0x00090000,
 0x000A0000,0x000B0000,0x000C0000,0x000D0000,
 0x000E0000,0x000F0000};

 // Sector addresses
 const unsigned long  SectorLength_B1M[]=
{0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,0x00004000,
 0x00004000,0x00004000,0x00004000,0x00004000,
 0x00004000,0x00004000};

// device definition for B1M
const struct FlashDef FlashDef_B1M =
{
  0x00000A5F,
  NUM_OF_BANKS_B1M,
  NUM_OF_SECTORS_B1M,
  BankOrg_B1M,
  SectorOrg_B1M,
  SectorAdd_B1M,
  SectorLength_B1M,
} ;


const struct FlashDef * const FlashDevices[] =
{
  &FlashDef_A256,
  &FlashDef_A768,
  &FlashDef_B768,
  &FlashDef_A288,
  &FlashDef_B1M,
} ;





// the "current" flash device
static const struct FlashDef *FlashDevice ;

#define NUM_OF_FLASH_DEVICES ( sizeof( FlashDevices ) / sizeof( struct FlashDef * ) )


// will be filled with high address of the sectors
__no_init static unsigned long FlashAddressTable[MAX_NUM_OF_SECTORS] ;

//===========================================================================
#ifdef __cplusplus
}       // end of extern "C"
#endif

#endif  // end of tms470r1a256_flash_definition

//===========================================================================
// End of file
//===========================================================================

